@@ -36,28 +36,28 @@ from google.resumable_media import _helpers
 from google.resumable_media import common
 
 
-_CONTENT_TYPE_HEADER = u'content-type'
-_CONTENT_RANGE_TEMPLATE = u'bytes {:d}-{:d}/{:d}'
-_RANGE_UNKNOWN_TEMPLATE = u'bytes {:d}-{:d}/*'
-_EMPTY_RANGE_TEMPLATE = u'bytes */{:d}'
-_BOUNDARY_WIDTH = len(repr(sys.maxsize - 1))
-_BOUNDARY_FORMAT = u'==============={{:0{:d}d}}=='.format(_BOUNDARY_WIDTH)
-_MULTIPART_SEP = b'--'
-_CRLF = b'\r\n'
-_MULTIPART_BEGIN = (
-    b'\r\ncontent-type: application/json; charset=UTF-8\r\n\r\n')
+_CONTENT_TYPE_HEADER = u"content-type"
+_CONTENT_RANGE_TEMPLATE = u"bytes {:d}-{:d}/{:d}"
+_RANGE_UNKNOWN_TEMPLATE = u"bytes {:d}-{:d}/*"
+_EMPTY_RANGE_TEMPLATE = u"bytes */{:d}"
+_BOUNDARY_WIDTH = len(str(sys.maxsize - 1))
+_BOUNDARY_FORMAT = u"==============={{:0{:d}d}}==".format(_BOUNDARY_WIDTH)
+_MULTIPART_SEP = b"--"
+_CRLF = b"\r\n"
+_MULTIPART_BEGIN = b"\r\ncontent-type: application/json; charset=UTF-8\r\n\r\n"
 _RELATED_HEADER = b'multipart/related; boundary="'
-_BYTES_RANGE_RE = re.compile(
-    r'bytes=0-(?P<end_byte>\d+)', flags=re.IGNORECASE)
+_BYTES_RANGE_RE = re.compile(r"bytes=0-(?P<end_byte>\d+)", flags=re.IGNORECASE)
 _STREAM_ERROR_TEMPLATE = (
-    u'Bytes stream is in unexpected state. '
-    u'The local stream has had {:d} bytes read from it while '
-    u'{:d} bytes have already been updated (they should match).')
+    u"Bytes stream is in unexpected state. "
+    u"The local stream has had {:d} bytes read from it while "
+    u"{:d} bytes have already been updated (they should match)."
+)
 _STREAM_READ_PAST_TEMPLATE = (
-    u'{:d} bytes have been read from the stream, which exceeds '
-    u'the expected total {:d}.')
-_POST = u'POST'
-_PUT = u'PUT'
+    u"{:d} bytes have been read from the stream, which exceeds "
+    u"the expected total {:d}."
+)
+_POST = u"POST"
+_PUT = u"PUT"
 
 
 class UploadBase(object):
@@ -106,8 +106,7 @@ class UploadBase(object):
         # Tombstone the current upload so it cannot be used again (in either
         # failure or success).
         self._finished = True
-        _helpers.require_status_code(
-            response, (http_client.OK,), self._get_status_code)
+        _helpers.require_status_code(response, (http_client.OK,), self._get_status_code)
 
     @staticmethod
     def _get_status_code(response):
@@ -119,7 +118,7 @@ class UploadBase(object):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
     @staticmethod
     def _get_headers(response):
@@ -131,7 +130,7 @@ class UploadBase(object):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
     @staticmethod
     def _get_body(response):
@@ -143,7 +142,7 @@ class UploadBase(object):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
 
 class SimpleUpload(UploadBase):
@@ -192,10 +191,10 @@ class SimpleUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         if self.finished:
-            raise ValueError(u'An upload can only be used once.')
+            raise ValueError(u"An upload can only be used once.")
 
         if not isinstance(data, six.binary_type):
-            raise TypeError(u'`data` must be bytes, received', type(data))
+            raise TypeError(u"`data` must be bytes, received", type(data))
         self._headers[_CONTENT_TYPE_HEADER] = content_type
         return _POST, self.upload_url, data, self._headers
 
@@ -212,7 +211,7 @@ class SimpleUpload(UploadBase):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
 
 class MultipartUpload(UploadBase):
@@ -264,12 +263,13 @@ class MultipartUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         if self.finished:
-            raise ValueError(u'An upload can only be used once.')
+            raise ValueError(u"An upload can only be used once.")
 
         if not isinstance(data, six.binary_type):
-            raise TypeError(u'`data` must be bytes, received', type(data))
+            raise TypeError(u"`data` must be bytes, received", type(data))
         content, multipart_boundary = construct_multipart_request(
-            data, metadata, content_type)
+            data, metadata, content_type
+        )
         multipart_content_type = _RELATED_HEADER + multipart_boundary + b'"'
         self._headers[_CONTENT_TYPE_HEADER] = multipart_content_type
         return _POST, self.upload_url, content, self._headers
@@ -289,7 +289,7 @@ class MultipartUpload(UploadBase):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
 
 class ResumableUpload(UploadBase):
@@ -319,7 +319,11 @@ class ResumableUpload(UploadBase):
     def __init__(self, upload_url, chunk_size, headers=None):
         super(ResumableUpload, self).__init__(upload_url, headers=headers)
         if chunk_size % resumable_media.UPLOAD_CHUNK_SIZE != 0:
-            raise ValueError(u'256 KB must divide chunk size')
+            raise ValueError(
+                u"{} KB must divide chunk size".format(
+                    resumable_media.UPLOAD_CHUNK_SIZE / 1024
+                )
+            )
         self._chunk_size = chunk_size
         self._stream = None
         self._content_type = None
@@ -366,8 +370,9 @@ class ResumableUpload(UploadBase):
         """
         return self._total_bytes
 
-    def _prepare_initiate_request(self, stream, metadata, content_type,
-                                  total_bytes=None, stream_final=True):
+    def _prepare_initiate_request(
+        self, stream, metadata, content_type, total_bytes=None, stream_final=True
+    ):
         """Prepare the contents of HTTP request to initiate upload.
 
         This is everything that must be done before a request that doesn't
@@ -405,15 +410,15 @@ class ResumableUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         if self.resumable_url is not None:
-            raise ValueError(u'This upload has already been initiated.')
+            raise ValueError(u"This upload has already been initiated.")
         if stream.tell() != 0:
-            raise ValueError(u'Stream must be at beginning.')
+            raise ValueError(u"Stream must be at beginning.")
 
         self._stream = stream
         self._content_type = content_type
         headers = {
-            _CONTENT_TYPE_HEADER: u'application/json; charset=UTF-8',
-            u'x-upload-content-type': content_type,
+            _CONTENT_TYPE_HEADER: u"application/json; charset=UTF-8",
+            u"x-upload-content-type": content_type,
         }
         # Set the total bytes if possible.
         if total_bytes is not None:
@@ -422,11 +427,11 @@ class ResumableUpload(UploadBase):
             self._total_bytes = get_total_bytes(stream)
         # Add the total bytes to the headers if set.
         if self._total_bytes is not None:
-            content_length = u'{:d}'.format(self._total_bytes)
-            headers[u'x-upload-content-length'] = content_length
+            content_length = u"{:d}".format(self._total_bytes)
+            headers[u"x-upload-content-length"] = content_length
 
         headers.update(self._headers)
-        payload = json.dumps(metadata).encode(u'utf-8')
+        payload = json.dumps(metadata).encode(u"utf-8")
         return _POST, self.upload_url, payload, headers
 
     def _process_initiate_response(self, response):
@@ -445,11 +450,25 @@ class ResumableUpload(UploadBase):
 
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
+        _helpers.require_status_code(
+            response,
+            (http_client.OK,),
+            self._get_status_code,
+            callback=self._make_invalid,
+        )
         self._resumable_url = _helpers.header_required(
-            response, u'location', self._get_headers)
+            response, u"location", self._get_headers
+        )
 
-    def initiate(self, transport, stream, metadata, content_type,
-                 total_bytes=None, stream_final=True):
+    def initiate(
+        self,
+        transport,
+        stream,
+        metadata,
+        content_type,
+        total_bytes=None,
+        stream_final=True,
+    ):
         """Initiate a resumable upload.
 
         By default, this method assumes your ``stream`` is in a "final"
@@ -484,7 +503,7 @@ class ResumableUpload(UploadBase):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
     def _prepare_request(self):
         """Prepare the contents of HTTP request to upload a chunk.
@@ -517,20 +536,22 @@ class ResumableUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         if self.finished:
-            raise ValueError(u'Upload has finished.')
+            raise ValueError(u"Upload has finished.")
         if self.invalid:
             raise ValueError(
-                u'Upload is in an invalid state. To recover call `recover()`.')
+                u"Upload is in an invalid state. To recover call `recover()`."
+            )
         if self.resumable_url is None:
             raise ValueError(
-                u'This upload has not been initiated. Please call '
-                u'initiate() before beginning to transmit chunks.')
+                u"This upload has not been initiated. Please call "
+                u"initiate() before beginning to transmit chunks."
+            )
 
-        start_byte, end_byte, payload, content_range = get_next_chunk(
-            self._stream, self._chunk_size, self._total_bytes)
+        start_byte, payload, content_range = get_next_chunk(
+            self._stream, self._chunk_size, self._total_bytes
+        )
         if start_byte != self.bytes_uploaded:
-            msg = _STREAM_ERROR_TEMPLATE.format(
-                start_byte, self.bytes_uploaded)
+            msg = _STREAM_ERROR_TEMPLATE.format(start_byte, self.bytes_uploaded)
             raise ValueError(msg)
 
         headers = {
@@ -570,8 +591,11 @@ class ResumableUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         status_code = _helpers.require_status_code(
-            response, (http_client.OK, resumable_media.PERMANENT_REDIRECT),
-            self._get_status_code, callback=self._make_invalid)
+            response,
+            (http_client.OK, resumable_media.PERMANENT_REDIRECT),
+            self._get_status_code,
+            callback=self._make_invalid,
+        )
         if status_code == http_client.OK:
             # NOTE: We use the "local" information of ``bytes_sent`` to update
             #       ``bytes_uploaded``, but do not verify this against other
@@ -586,15 +610,21 @@ class ResumableUpload(UploadBase):
             self._finished = True
         else:
             bytes_range = _helpers.header_required(
-                response, _helpers.RANGE_HEADER,
-                self._get_headers, callback=self._make_invalid)
+                response,
+                _helpers.RANGE_HEADER,
+                self._get_headers,
+                callback=self._make_invalid,
+            )
             match = _BYTES_RANGE_RE.match(bytes_range)
             if match is None:
                 self._make_invalid()
                 raise common.InvalidResponse(
-                    response, u'Unexpected "range" header', bytes_range,
-                    u'Expected to be of the form "bytes=0-{end}"')
-            self._bytes_uploaded = int(match.group(u'end_byte')) + 1
+                    response,
+                    u'Unexpected "range" header',
+                    bytes_range,
+                    u'Expected to be of the form "bytes=0-{end}"',
+                )
+            self._bytes_uploaded = int(match.group(u"end_byte")) + 1
 
     def transmit_next_chunk(self, transport):
         """Transmit the next chunk of the resource to be uploaded.
@@ -611,7 +641,7 @@ class ResumableUpload(UploadBase):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
     def _prepare_recover_request(self):
         """Prepare the contents of HTTP request to recover from failure.
@@ -639,10 +669,9 @@ class ResumableUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         if not self.invalid:
-            raise ValueError(
-                u'Upload is not in invalid state, no need to recover.')
+            raise ValueError(u"Upload is not in invalid state, no need to recover.")
 
-        headers = {_helpers.CONTENT_RANGE_HEADER: u'bytes */*'}
+        headers = {_helpers.CONTENT_RANGE_HEADER: u"bytes */*"}
         return _PUT, self.resumable_url, None, headers
 
     def _process_recover_response(self, response):
@@ -665,17 +694,20 @@ class ResumableUpload(UploadBase):
         .. _sans-I/O: https://sans-io.readthedocs.io/
         """
         _helpers.require_status_code(
-            response, (resumable_media.PERMANENT_REDIRECT,),
-            self._get_status_code)
+            response, (resumable_media.PERMANENT_REDIRECT,), self._get_status_code
+        )
         headers = self._get_headers(response)
         if _helpers.RANGE_HEADER in headers:
             bytes_range = headers[_helpers.RANGE_HEADER]
             match = _BYTES_RANGE_RE.match(bytes_range)
             if match is None:
                 raise common.InvalidResponse(
-                    response, u'Unexpected "range" header', bytes_range,
-                    u'Expected to be of the form "bytes=0-{end}"')
-            self._bytes_uploaded = int(match.group(u'end_byte')) + 1
+                    response,
+                    u'Unexpected "range" header',
+                    bytes_range,
+                    u'Expected to be of the form "bytes=0-{end}"',
+                )
+            self._bytes_uploaded = int(match.group(u"end_byte")) + 1
         else:
             # In this case, the upload has not "begun".
             self._bytes_uploaded = 0
@@ -700,7 +732,7 @@ class ResumableUpload(UploadBase):
         Raises:
             NotImplementedError: Always, since virtual.
         """
-        raise NotImplementedError(u'This implementation is virtual.')
+        raise NotImplementedError(u"This implementation is virtual.")
 
 
 def get_boundary():
@@ -713,7 +745,7 @@ def get_boundary():
     boundary = _BOUNDARY_FORMAT.format(random_int)
     # NOTE: Neither % formatting nor .format() are available for byte strings
     #       in Python 3.4, so we must use unicode strings as templates.
-    return boundary.encode(u'utf-8')
+    return boundary.encode(u"utf-8")
 
 
 def construct_multipart_request(data, metadata, content_type):
@@ -732,20 +764,27 @@ def construct_multipart_request(data, metadata, content_type):
         between each part.
     """
     multipart_boundary = get_boundary()
-    json_bytes = json.dumps(metadata).encode(u'utf-8')
-    content_type = content_type.encode(u'utf-8')
+    json_bytes = json.dumps(metadata).encode(u"utf-8")
+    content_type = content_type.encode(u"utf-8")
     # Combine the two parts into a multipart payload.
     # NOTE: We'd prefer a bytes template but are restricted by Python 3.4.
     boundary_sep = _MULTIPART_SEP + multipart_boundary
     content = (
-        boundary_sep +
-        _MULTIPART_BEGIN +
-        json_bytes + _CRLF +
-        boundary_sep + _CRLF +
-        b'content-type: ' + content_type + _CRLF +
-        _CRLF +  # Empty line between headers and body.
-        data + _CRLF +
-        boundary_sep + _MULTIPART_SEP)
+        boundary_sep
+        + _MULTIPART_BEGIN
+        + json_bytes
+        + _CRLF
+        + boundary_sep
+        + _CRLF
+        + b"content-type: "
+        + content_type
+        + _CRLF
+        + _CRLF
+        + data  # Empty line between headers and body.
+        + _CRLF
+        + boundary_sep
+        + _MULTIPART_SEP
+    )
 
     return content, multipart_boundary
 
@@ -784,14 +823,15 @@ def get_next_chunk(stream, chunk_size, total_bytes):
             in the ``stream``.
 
     Returns:
-        Tuple[int, int, bytes, str]: Quadruple of:
+        Tuple[int, bytes, str]: Triple of:
 
           * the start byte index
-          * the end byte index
           * the content in between the start and end bytes (inclusive)
           * content range header for the chunk (slice) that has been read
 
     Raises:
+        ValueError: If ``total_bytes == 0`` but ``stream.read()`` yields
+            non-empty content.
         ValueError: If there is no data left to consume. This corresponds
             exactly to the case ``end_byte < start_byte``, which can only
             occur if ``end_byte == start_byte - 1``.
@@ -807,17 +847,26 @@ def get_next_chunk(stream, chunk_size, total_bytes):
         if num_bytes_read < chunk_size:
             # We now **KNOW** the total number of bytes.
             total_bytes = end_byte + 1
+    elif total_bytes == 0:
+        # NOTE: We also expect ``start_byte == 0`` here but don't check
+        #       because ``_prepare_initiate_request()`` requires the
+        #       stream to be at the beginning.
+        if num_bytes_read != 0:
+            raise ValueError(
+                u"Stream specified as empty, but produced non-empty content."
+            )
     else:
         if num_bytes_read == 0:
             raise ValueError(
-                u'Stream is already exhausted. There is no content remaining.')
+                u"Stream is already exhausted. There is no content remaining."
+            )
 
         if end_byte >= total_bytes:
             msg = _STREAM_READ_PAST_TEMPLATE.format(end_byte + 1, total_bytes)
             raise ValueError(msg)
 
     content_range = get_content_range(start_byte, end_byte, total_bytes)
-    return start_byte, end_byte, payload, content_range
+    return start_byte, payload, content_range
 
 
 def get_content_range(start_byte, end_byte, total_bytes):
@@ -840,10 +889,8 @@ def get_content_range(start_byte, end_byte, total_bytes):
         str: The content range header.
     """
     if total_bytes is None:
-        return _RANGE_UNKNOWN_TEMPLATE.format(
-            start_byte, end_byte)
+        return _RANGE_UNKNOWN_TEMPLATE.format(start_byte, end_byte)
     elif end_byte < start_byte:
         return _EMPTY_RANGE_TEMPLATE.format(total_bytes)
     else:
-        return _CONTENT_RANGE_TEMPLATE.format(
-            start_byte, end_byte, total_bytes)
+        return _CONTENT_RANGE_TEMPLATE.format(start_byte, end_byte, total_bytes)
